@@ -48,6 +48,11 @@ from typing import (
     Type,
     TypeVar,
 )
+
+try:
+    from typing import TypeAlias
+except ImportError:
+    from typing_extensions import TypeAlias  # Python 3.9 or earlier
 from urllib.parse import quote
 import yaml
 
@@ -76,7 +81,8 @@ try:
 
     gi.require_version("Gtk", "3.0")
     from gi.repository import GLib, Gtk, Gdk, GdkPixbuf  # type: ignore
-    from Gtk import MessageDialog  # type: ignore
+
+    MessageDialog = Gtk.MessageDialog
 except (ImportError, ValueError):
     # "ValueError('Namespace %s not available' % namespace)"
     gi = None
@@ -84,6 +90,7 @@ except (ImportError, ValueError):
     class MessageDialog:  # type: ignore
         pass
 
+
 __epilog__ = """ This program will upload the provided files on the internet and
 notify the user when completed. The resulting URL will also be copied
 to the clipboard. Preprocessors can do fancy things before (only
@@ -583,7 +590,7 @@ thumb_video_delay = '3'
 """
 
 
-class TimerWindow(MessageDialog):  # type: ignore[misc]
+class TimerWindow(MessageDialog):  # type: ignore[misc, valid-type]
     """This widget will show a timer and a spinner in a window for the
     given delay, then close the dialog.
 
@@ -1072,6 +1079,9 @@ def secret_token() -> Tuple[str, str]:
     return datetime.now().strftime("%Y-%m-%d"), secrets.token_urlsafe()
 
 
+SupportedExtensions: TypeAlias = Literal["png", "jpg", "txt", "html"]
+
+
 class BaseClipboard:
     def __init__(self, selection: Literal["CLIPBOARD", "PRIMARY"]) -> None:
         """configure the clipboard, based on whether the clipboard is PRIMARY
@@ -1088,7 +1098,7 @@ class BaseClipboard:
     def put_image(self, path: bytes) -> bool:
         raise NotImplementedError()
 
-    def get(self) -> Tuple[Optional[bytes], Optional[Literal["png", "jpg", "txt"]]]:
+    def get(self) -> Tuple[Optional[bytes], Optional[SupportedExtensions]]:
         raise NotImplementedError()
 
 
@@ -1181,7 +1191,7 @@ class GtkClipboard(BaseClipboard):
             # we use _exit() to avoid firing atexit() in double
             os._exit(0)
 
-    def get(self) -> Tuple[Optional[bytes], Optional[Literal["png", "jpg", "txt"]]]:
+    def get(self) -> Tuple[Optional[bytes], Optional[Literal["png", "txt"]]]:
         """get the clipboard content, possible as an image or, failing that, as text
 
         GTK clipboards also support "rich text" and "URI", but I'm not
@@ -1243,12 +1253,12 @@ class WaylandClipboard(BaseClipboard):
             logging.warning("could not copy to clipboard with: %r", command)
             return False
 
-    def get(self) -> Tuple[Optional[bytes], Optional[Literal["png", "jpg", "txt"]]]:
+    def get(self) -> Tuple[Optional[bytes], Optional[SupportedExtensions]]:
         command = ["wl-paste", "--list-types"] + self.extra
         logging.debug("listing supported types with %s", command)
         mimetype_output = subprocess.run(command, stdout=subprocess.PIPE)
         mimetypes = mimetype_output.stdout.decode("ascii").split("\n")
-        extension: Optional[Literal["png", "jpg", "txt"]] = None
+        extension: Optional[SupportedExtensions] = None
         if mimetypes == ["No selection"]:
             return None, None
         if "image/png" in mimetypes:
@@ -1257,6 +1267,12 @@ class WaylandClipboard(BaseClipboard):
         elif "image/jpeg" in mimetypes:
             extension = "jpg"
             mimetype = "image/jpeg"
+        elif "text/html" in mimetypes:
+            extension = "html"
+            mimetype = "text/html"
+        elif "text/plain;charset=utf-8" in mimetypes:
+            extension = "txt"
+            mimetype = "text/plain;charset=utf-8"
         elif "text/plain" in mimetypes:
             extension = "txt"
             mimetype = "text/plain"
@@ -1520,7 +1536,7 @@ def main() -> None:
 
         # dump file contents we know is terminal-safe
         if path in dump_content:
-            with open(path) as fp:
+            with open(path, "rb") as fp:
                 print("uploading content: %r" % fp.read())
         assert args.output.endswith("/")
 
